Databunnystoragedriver contains code forked from iXsystem cinder driver code under BSD license. https://github.com/iXsystems/cinder

The purpose of this repository is provide a python package that can be easily installed seperate from Openstack cinder volume driver package
https://github.com/openstack/cinder

